/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { IconsService } from '@progress/kendo-angular-icons';
import { DialogComponent } from './dialog/dialog.component';
import { DialogTitleBarComponent } from './dialog/dialog-titlebar.component';
import { DialogService } from './dialog/dialog.service';
import { DialogContainerService } from './dialog/dialog-container.service';
import { KENDO_DIALOG } from './directives';
import * as i0 from "@angular/core";
import * as i1 from "./dialog/dialog.component";
import * as i2 from "./dialog/dialog-titlebar.component";
import * as i3 from "./dialog/dialog-container.directive";
import * as i4 from "./dialog/dialog-actions.component";
import * as i5 from "./localization/custom-messages.component";
/**
 * @hidden
 */
export const DIALOG_DIRECTIVES = [
    DialogComponent,
    DialogTitleBarComponent
];
//IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Dialog component that includes all Dialog components and directives.
 * Imports `DialogModule` into the [root module](link:site.data.urls.angular['ngmodules']#angular-modularity)
 * of your application or into any other sub-module that will use the Dialog component.
 *
 * @example
 * ```ts-no-run
 * import { NgModule } from '@angular/core';
 * import { BrowserModule } from '@angular/platform-browser';
 * import { DialogModule } from '@progress/kendo-angular-dialog';
 * import { AppComponent } from './app.component';
 *
 * _@NgModule({
 *     bootstrap:    [AppComponent],
 *     declarations: [AppComponent],
 *     imports:      [BrowserModule, DialogModule]
 * })
 * export class AppModule {
 * }
 * ```
 */
export class DialogModule {
}
DialogModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DialogModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: DialogModule, imports: [i1.DialogComponent, i2.DialogTitleBarComponent, i3.DialogContainerDirective, i4.DialogActionsComponent, i5.CustomMessagesComponent], exports: [i1.DialogComponent, i2.DialogTitleBarComponent, i3.DialogContainerDirective, i4.DialogActionsComponent, i5.CustomMessagesComponent] });
DialogModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DialogModule, providers: [DialogContainerService, DialogService, IconsService], imports: [i1.DialogComponent, i2.DialogTitleBarComponent, i4.DialogActionsComponent] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DialogModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_DIALOG],
                    imports: [...KENDO_DIALOG],
                    providers: [DialogContainerService, DialogService, IconsService]
                }]
        }] });
